@@ -1,4 +1,5 @@
 import os
+import sys
 import logging
 
 from dotenv import load_dotenv
@@ -8,6 +9,7 @@ env_path = Path('.') / '.env'
 load_dotenv(dotenv_path=env_path)
 
 logging.basicConfig(
+    stream=sys.stdout,
     level=os.environ.get('CHAOTIC_LOG_LEVEL', 'INFO').upper(),
     format='%(asctime)s - %(name)s:%(levelname)s:%(message)s')
 
